@@ -1,12 +1,20 @@
-__all__ = ["ForwardedArgs", "normalize_node_name", "hexdump", "hexload", "is_ci"]
+__all__ = [
+    "normalize_node_name",
+    "node_path_name",
+    "hexdump",
+    "hexload",
+    "is_ci",
+    "pluralize",
+]
 
 
 import math
 import os
 import re
-from typing import Any, Dict, Tuple
+from pathlib import Path
+from typing import Any, Tuple
 
-ForwardedArgs = Tuple[Tuple[Any, ...], Dict[str, Any]]
+from _pytest import python
 
 
 def normalize_node_name(name: str):
@@ -15,6 +23,19 @@ def normalize_node_name(name: str):
     ).strip("_")
 
 
+def node_path_name(node: Any) -> Tuple[Path, str]:
+    hierarchy = [normalize_node_name(node.name)]
+
+    while not isinstance(node, python.Module):
+        node = node.parent
+        hierarchy.append(normalize_node_name(node.name))
+
+    return (
+        Path(node.fspath).relative_to(Path(".").resolve()),
+        "__".join(reversed(hierarchy)),
+    )
+
+
 def hexdump(data: bytes, n: int = 16):
     for k, i in enumerate(range((len(data) + n - 1) // n)):
         values = data[i * n : (i + 1) * n]
@@ -29,3 +50,7 @@ def hexload(dump: str):
 
 def is_ci():
     return "CI" in os.environ or "TF_BUILD" in os.environ
+
+
+def pluralize(word: str, count: int) -> str:
+    return f"{count} {word}" + "s" * (count > 1)
